@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -31,7 +31,7 @@ public:
     explicit ConfigureCustomSettingDialog(QWidget *parent = Q_NULLPTR);
     ~ConfigureCustomSettingDialog();
     void setRule(const QString &rule);
-    QString rule();
+    QString rule() const;
 private:
     ConfigureCustomSettingWidget *mCustomSettingWidget;
 };
