@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -26,8 +26,7 @@ KDEApplicationTreeListWidgetItem::KDEApplicationTreeListWidgetItem(const QString
     : QTreeWidgetItem(parent),
       mCategory(category)
 {
-    setCheckState(Description, Qt::Checked);
-    mCategoryTypeCombobox = new CategoryTypeComboBox;
+    mCategoryTypeCombobox = new CategoryTypeComboBox(false);
     treeWidget()->setItemWidget(this, CategoryType, mCategoryTypeCombobox);
 }
 
@@ -36,7 +35,7 @@ KDEApplicationTreeListWidgetItem::~KDEApplicationTreeListWidgetItem()
 
 }
 
-void KDEApplicationTreeListWidgetItem::setType(const QString &type)
+void KDEApplicationTreeListWidgetItem::setType(LoggingCategory::LoggingType type)
 {
     mCategoryTypeCombobox->setType(type);
 }
@@ -51,12 +50,12 @@ void KDEApplicationTreeListWidgetItem::setLogName(const QString &category)
     mCategory = category;
 }
 
-Category KDEApplicationTreeListWidgetItem::rule()
+LoggingCategory KDEApplicationTreeListWidgetItem::rule()
 {
-    Category cat;
-    cat.enabled = checkState(Description) == Qt::Checked;
+    LoggingCategory cat;
+    cat.enabled = false;
     cat.logName = mCategory;
-    cat.type = mCategoryTypeCombobox->type();
+    cat.loggingType = mCategoryTypeCombobox->type();
     return cat;
 }
 
@@ -76,49 +75,48 @@ KDEApplicationTreeListWidget::~KDEApplicationTreeListWidget()
 void KDEApplicationTreeListWidget::selectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        QTreeWidgetItem *itemWidget = topLevelItem(i);
-        itemWidget->setCheckState(KDEApplicationTreeListWidgetItem::Description, Qt::Checked);
+        KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        itemWidget->setType(LoggingCategory::Info);
     }
 }
 
 void KDEApplicationTreeListWidget::deSelectAllDebugCategories()
 {
     for (int i = 0; i < topLevelItemCount(); ++i) {
-        QTreeWidgetItem *itemWidget = topLevelItem(i);
-        itemWidget->setCheckState(KDEApplicationTreeListWidgetItem::Description, Qt::Unchecked);
+        KDEApplicationTreeListWidgetItem *itemWidget = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
+        itemWidget->setType(LoggingCategory::Off);
     }
 }
 
-void KDEApplicationTreeListWidget::fillList(const Category::List &list)
+void KDEApplicationTreeListWidget::fillList(const LoggingCategory::List &list)
 {
     addListItems(list, true);
 }
 
-void KDEApplicationTreeListWidget::addListItems(const Category::List &list, bool clearList)
+void KDEApplicationTreeListWidget::addListItems(const LoggingCategory::List &list, bool clearList)
 {
     if (clearList) {
         clear();
     }
-    Q_FOREACH (const Category &cat, list) {
+    Q_FOREACH (const LoggingCategory &cat, list) {
         KDEApplicationTreeListWidgetItem *item = new KDEApplicationTreeListWidgetItem(cat.logName, this);
         item->setText(KDEApplicationTreeListWidgetItem::Description, cat.description);
-        item->setCheckState(KDEApplicationTreeListWidgetItem::Description, cat.enabled ? Qt::Checked : Qt::Unchecked);
-        item->setType(cat.type);
+        item->setType(cat.loggingType);
     }
     resizeColumnToContents(KDEApplicationTreeListWidgetItem::Description);
 }
 
-void KDEApplicationTreeListWidget::insertCategories(const Category::List &list)
+void KDEApplicationTreeListWidget::insertCategories(const LoggingCategory::List &list)
 {
     addListItems(list, false);
 }
 
-Category::List KDEApplicationTreeListWidget::rules()
+LoggingCategory::List KDEApplicationTreeListWidget::rules()
 {
-    Category::List lst;
+    LoggingCategory::List lst;
     for (int i = 0; i < topLevelItemCount(); ++i) {
         KDEApplicationTreeListWidgetItem *listWidgetItem = static_cast<KDEApplicationTreeListWidgetItem *>(topLevelItem(i));
-        Category cat = listWidgetItem->rule();
+        LoggingCategory cat = listWidgetItem->rule();
         if (cat.isValid()) {
             lst.append(cat);
         }
